<?php
// (GenCodeChecksum:IGNORE)

return [
  'CRM_Core_DAO_AddressFormat' => [
    'name' => 'AddressFormat',
    'class' => 'CRM_Core_DAO_AddressFormat',
    'table' => 'civicrm_address_format',
  ],
  'CRM_Core_DAO_Extension' => [
    'name' => 'Extension',
    'class' => 'CRM_Core_DAO_Extension',
    'table' => 'civicrm_extension',
  ],
  'CRM_Core_DAO_LocationType' => [
    'name' => 'LocationType',
    'class' => 'CRM_Core_DAO_LocationType',
    'table' => 'civicrm_location_type',
  ],
  'CRM_Core_DAO_Managed' => [
    'name' => 'Managed',
    'class' => 'CRM_Core_DAO_Managed',
    'table' => 'civicrm_managed',
  ],
  'CRM_Core_DAO_Mapping' => [
    'name' => 'Mapping',
    'class' => 'CRM_Core_DAO_Mapping',
    'table' => 'civicrm_mapping',
  ],
  'CRM_Core_DAO_MessageTemplate' => [
    'name' => 'MessageTemplate',
    'class' => 'CRM_Core_DAO_MessageTemplate',
    'table' => 'civicrm_msg_template',
  ],
  'CRM_Core_DAO_OptionGroup' => [
    'name' => 'OptionGroup',
    'class' => 'CRM_Core_DAO_OptionGroup',
    'table' => 'civicrm_option_group',
  ],
  'CRM_Core_DAO_PreferencesDate' => [
    'name' => 'PreferencesDate',
    'class' => 'CRM_Core_DAO_PreferencesDate',
    'table' => 'civicrm_preferences_date',
  ],
  'CRM_Core_DAO_SystemLog' => [
    'name' => 'SystemLog',
    'class' => 'CRM_Core_DAO_SystemLog',
    'table' => 'civicrm_system_log',
  ],
  'CRM_Core_DAO_Worldregion' => [
    'name' => 'Worldregion',
    'class' => 'CRM_Core_DAO_Worldregion',
    'table' => 'civicrm_worldregion',
  ],
  'CRM_Core_DAO_Component' => [
    'name' => 'Component',
    'class' => 'CRM_Core_DAO_Component',
    'table' => 'civicrm_component',
  ],
  'CRM_Core_DAO_Persistent' => [
    'name' => 'Persistent',
    'class' => 'CRM_Core_DAO_Persistent',
    'table' => 'civicrm_persistent',
  ],
  'CRM_Core_DAO_PrevNextCache' => [
    'name' => 'PrevNextCache',
    'class' => 'CRM_Core_DAO_PrevNextCache',
    'table' => 'civicrm_prevnext_cache',
  ],
  'CRM_Core_DAO_ActionMapping' => [
    'name' => 'ActionMapping',
    'class' => 'CRM_Core_DAO_ActionMapping',
    'table' => 'civicrm_action_mapping',
  ],
  'CRM_Core_DAO_RecurringEntity' => [
    'name' => 'RecurringEntity',
    'class' => 'CRM_Core_DAO_RecurringEntity',
    'table' => 'civicrm_recurring_entity',
  ],
  'CRM_ACL_DAO_ACL' => [
    'name' => 'ACL',
    'class' => 'CRM_ACL_DAO_ACL',
    'table' => 'civicrm_acl',
  ],
  'CRM_ACL_DAO_EntityRole' => [
    'name' => 'EntityRole',
    'class' => 'CRM_ACL_DAO_EntityRole',
    'table' => 'civicrm_acl_entity_role',
  ],
  'CRM_Contact_DAO_Contact' => [
    'name' => 'Contact',
    'class' => 'CRM_Contact_DAO_Contact',
    'table' => 'civicrm_contact',
  ],
  'CRM_Contact_DAO_ACLContactCache' => [
    'name' => 'ACLContactCache',
    'class' => 'CRM_Contact_DAO_ACLContactCache',
    'table' => 'civicrm_acl_contact_cache',
  ],
  'CRM_Contact_DAO_RelationshipType' => [
    'name' => 'RelationshipType',
    'class' => 'CRM_Contact_DAO_RelationshipType',
    'table' => 'civicrm_relationship_type',
  ],
  'CRM_Contact_DAO_SavedSearch' => [
    'name' => 'SavedSearch',
    'class' => 'CRM_Contact_DAO_SavedSearch',
    'table' => 'civicrm_saved_search',
  ],
  'CRM_Contact_DAO_ContactType' => [
    'name' => 'ContactType',
    'class' => 'CRM_Contact_DAO_ContactType',
    'table' => 'civicrm_contact_type',
  ],
  'CRM_Batch_DAO_Batch' => [
    'name' => 'Batch',
    'class' => 'CRM_Batch_DAO_Batch',
    'table' => 'civicrm_batch',
  ],
  'CRM_Batch_DAO_EntityBatch' => [
    'name' => 'EntityBatch',
    'class' => 'CRM_Batch_DAO_EntityBatch',
    'table' => 'civicrm_entity_batch',
  ],
  'CRM_Mailing_DAO_MailingComponent' => [
    'name' => 'MailingComponent',
    'class' => 'CRM_Mailing_DAO_MailingComponent',
    'table' => 'civicrm_mailing_component',
  ],
  'CRM_Mailing_DAO_MailingAB' => [
    'name' => 'MailingAB',
    'class' => 'CRM_Mailing_DAO_MailingAB',
    'table' => 'civicrm_mailing_abtest',
  ],
  'CRM_Mailing_DAO_BounceType' => [
    'name' => 'BounceType',
    'class' => 'CRM_Mailing_DAO_BounceType',
    'table' => 'civicrm_mailing_bounce_type',
  ],
  'CRM_Mailing_DAO_BouncePattern' => [
    'name' => 'BouncePattern',
    'class' => 'CRM_Mailing_DAO_BouncePattern',
    'table' => 'civicrm_mailing_bounce_pattern',
  ],
  'CRM_Contribute_DAO_Premium' => [
    'name' => 'Premium',
    'class' => 'CRM_Contribute_DAO_Premium',
    'table' => 'civicrm_premiums',
  ],
  'CRM_Financial_DAO_Currency' => [
    'name' => 'Currency',
    'class' => 'CRM_Financial_DAO_Currency',
    'table' => 'civicrm_currency',
  ],
  'CRM_Financial_DAO_FinancialAccount' => [
    'name' => 'FinancialAccount',
    'class' => 'CRM_Financial_DAO_FinancialAccount',
    'table' => 'civicrm_financial_account',
  ],
  'CRM_Financial_DAO_PaymentProcessorType' => [
    'name' => 'PaymentProcessorType',
    'class' => 'CRM_Financial_DAO_PaymentProcessorType',
    'table' => 'civicrm_payment_processor_type',
  ],
  'CRM_Financial_DAO_FinancialType' => [
    'name' => 'FinancialType',
    'class' => 'CRM_Financial_DAO_FinancialType',
    'table' => 'civicrm_financial_type',
  ],
  'CRM_Financial_DAO_EntityFinancialAccount' => [
    'name' => 'EntityFinancialAccount',
    'class' => 'CRM_Financial_DAO_EntityFinancialAccount',
    'table' => 'civicrm_entity_financial_account',
  ],
  'CRM_Financial_DAO_FinancialItem' => [
    'name' => 'FinancialItem',
    'class' => 'CRM_Financial_DAO_FinancialItem',
    'table' => 'civicrm_financial_item',
  ],
  'CRM_Member_DAO_MembershipStatus' => [
    'name' => 'MembershipStatus',
    'class' => 'CRM_Member_DAO_MembershipStatus',
    'table' => 'civicrm_membership_status',
  ],
  'CRM_Campaign_DAO_Campaign' => [
    'name' => 'Campaign',
    'class' => 'CRM_Campaign_DAO_Campaign',
    'table' => 'civicrm_campaign',
  ],
  'CRM_Campaign_DAO_CampaignGroup' => [
    'name' => 'CampaignGroup',
    'class' => 'CRM_Campaign_DAO_CampaignGroup',
    'table' => 'civicrm_campaign_group',
  ],
  'CRM_Campaign_DAO_Survey' => [
    'name' => 'Survey',
    'class' => 'CRM_Campaign_DAO_Survey',
    'table' => 'civicrm_survey',
  ],
  'CRM_Event_DAO_ParticipantStatusType' => [
    'name' => 'ParticipantStatusType',
    'class' => 'CRM_Event_DAO_ParticipantStatusType',
    'table' => 'civicrm_participant_status_type',
  ],
  'CRM_Event_Cart_DAO_Cart' => [
    'name' => 'Cart',
    'class' => 'CRM_Event_Cart_DAO_Cart',
    'table' => 'civicrm_event_carts',
  ],
  'CRM_Dedupe_DAO_RuleGroup' => [
    'name' => 'RuleGroup',
    'class' => 'CRM_Dedupe_DAO_RuleGroup',
    'table' => 'civicrm_dedupe_rule_group',
  ],
  'CRM_Dedupe_DAO_Rule' => [
    'name' => 'Rule',
    'class' => 'CRM_Dedupe_DAO_Rule',
    'table' => 'civicrm_dedupe_rule',
  ],
  'CRM_Dedupe_DAO_Exception' => [
    'name' => 'Exception',
    'class' => 'CRM_Dedupe_DAO_Exception',
    'table' => 'civicrm_dedupe_exception',
  ],
  'CRM_Case_DAO_CaseType' => [
    'name' => 'CaseType',
    'class' => 'CRM_Case_DAO_CaseType',
    'table' => 'civicrm_case_type',
  ],
  'CRM_Grant_DAO_Grant' => [
    'name' => 'Grant',
    'class' => 'CRM_Grant_DAO_Grant',
    'table' => 'civicrm_grant',
  ],
  'CRM_Friend_DAO_Friend' => [
    'name' => 'Friend',
    'class' => 'CRM_Friend_DAO_Friend',
    'table' => 'civicrm_tell_friend',
  ],
  'CRM_Pledge_DAO_PledgeBlock' => [
    'name' => 'PledgeBlock',
    'class' => 'CRM_Pledge_DAO_PledgeBlock',
    'table' => 'civicrm_pledge_block',
  ],
  'CRM_Queue_DAO_QueueItem' => [
    'name' => 'QueueItem',
    'class' => 'CRM_Queue_DAO_QueueItem',
    'table' => 'civicrm_queue_item',
  ],
  'CRM_PCP_DAO_PCP' => [
    'name' => 'PCP',
    'class' => 'CRM_PCP_DAO_PCP',
    'table' => 'civicrm_pcp',
  ],
  'CRM_Cxn_DAO_Cxn' => [
    'name' => 'Cxn',
    'class' => 'CRM_Cxn_DAO_Cxn',
    'table' => 'civicrm_cxn',
  ],
  'CRM_Core_DAO_Cache' => [
    'name' => 'Cache',
    'class' => 'CRM_Core_DAO_Cache',
    'table' => 'civicrm_cache',
  ],
  'CRM_Core_DAO_Country' => [
    'name' => 'Country',
    'class' => 'CRM_Core_DAO_Country',
    'table' => 'civicrm_country',
  ],
  'CRM_Core_DAO_CustomGroup' => [
    'name' => 'CustomGroup',
    'class' => 'CRM_Core_DAO_CustomGroup',
    'table' => 'civicrm_custom_group',
  ],
  'CRM_Core_DAO_CustomField' => [
    'name' => 'CustomField',
    'class' => 'CRM_Core_DAO_CustomField',
    'table' => 'civicrm_custom_field',
  ],
  'CRM_Core_DAO_Domain' => [
    'name' => 'Domain',
    'class' => 'CRM_Core_DAO_Domain',
    'table' => 'civicrm_domain',
  ],
  'CRM_Core_DAO_Email' => [
    'name' => 'Email',
    'class' => 'CRM_Core_DAO_Email',
    'table' => 'civicrm_email',
  ],
  'CRM_Core_DAO_File' => [
    'name' => 'File',
    'class' => 'CRM_Core_DAO_File',
    'table' => 'civicrm_file',
  ],
  'CRM_Core_DAO_IM' => [
    'name' => 'IM',
    'class' => 'CRM_Core_DAO_IM',
    'table' => 'civicrm_im',
  ],
  'CRM_Core_DAO_Job' => [
    'name' => 'Job',
    'class' => 'CRM_Core_DAO_Job',
    'table' => 'civicrm_job',
  ],
  'CRM_Core_DAO_JobLog' => [
    'name' => 'JobLog',
    'class' => 'CRM_Core_DAO_JobLog',
    'table' => 'civicrm_job_log',
  ],
  'CRM_Core_DAO_Log' => [
    'name' => 'Log',
    'class' => 'CRM_Core_DAO_Log',
    'table' => 'civicrm_log',
  ],
  'CRM_Core_DAO_MailSettings' => [
    'name' => 'MailSettings',
    'class' => 'CRM_Core_DAO_MailSettings',
    'table' => 'civicrm_mail_settings',
  ],
  'CRM_Core_DAO_MappingField' => [
    'name' => 'MappingField',
    'class' => 'CRM_Core_DAO_MappingField',
    'table' => 'civicrm_mapping_field',
  ],
  'CRM_Core_DAO_Menu' => [
    'name' => 'Menu',
    'class' => 'CRM_Core_DAO_Menu',
    'table' => 'civicrm_menu',
  ],
  'CRM_Core_DAO_Navigation' => [
    'name' => 'Navigation',
    'class' => 'CRM_Core_DAO_Navigation',
    'table' => 'civicrm_navigation',
  ],
  'CRM_Core_DAO_Note' => [
    'name' => 'Note',
    'class' => 'CRM_Core_DAO_Note',
    'table' => 'civicrm_note',
  ],
  'CRM_Core_DAO_OptionValue' => [
    'name' => 'OptionValue',
    'class' => 'CRM_Core_DAO_OptionValue',
    'table' => 'civicrm_option_value',
  ],
  'CRM_Core_DAO_Phone' => [
    'name' => 'Phone',
    'class' => 'CRM_Core_DAO_Phone',
    'table' => 'civicrm_phone',
  ],
  'CRM_Core_DAO_StateProvince' => [
    'name' => 'StateProvince',
    'class' => 'CRM_Core_DAO_StateProvince',
    'table' => 'civicrm_state_province',
  ],
  'CRM_Core_DAO_Tag' => [
    'name' => 'Tag',
    'class' => 'CRM_Core_DAO_Tag',
    'table' => 'civicrm_tag',
  ],
  'CRM_Core_DAO_UFMatch' => [
    'name' => 'UFMatch',
    'class' => 'CRM_Core_DAO_UFMatch',
    'table' => 'civicrm_uf_match',
  ],
  'CRM_Core_DAO_Timezone' => [
    'name' => 'Timezone',
    'class' => 'CRM_Core_DAO_Timezone',
    'table' => 'civicrm_timezone',
  ],
  'CRM_Core_DAO_OpenID' => [
    'name' => 'OpenID',
    'class' => 'CRM_Core_DAO_OpenID',
    'table' => 'civicrm_openid',
  ],
  'CRM_Core_DAO_Website' => [
    'name' => 'Website',
    'class' => 'CRM_Core_DAO_Website',
    'table' => 'civicrm_website',
  ],
  'CRM_Core_DAO_Setting' => [
    'name' => 'Setting',
    'class' => 'CRM_Core_DAO_Setting',
    'table' => 'civicrm_setting',
  ],
  'CRM_Core_DAO_PrintLabel' => [
    'name' => 'PrintLabel',
    'class' => 'CRM_Core_DAO_PrintLabel',
    'table' => 'civicrm_print_label',
  ],
  'CRM_Core_DAO_WordReplacement' => [
    'name' => 'WordReplacement',
    'class' => 'CRM_Core_DAO_WordReplacement',
    'table' => 'civicrm_word_replacement',
  ],
  'CRM_Core_DAO_StatusPreference' => [
    'name' => 'StatusPreference',
    'class' => 'CRM_Core_DAO_StatusPreference',
    'table' => 'civicrm_status_pref',
  ],
  'CRM_ACL_DAO_Cache' => [
    'name' => 'Cache',
    'class' => 'CRM_ACL_DAO_Cache',
    'table' => 'civicrm_acl_cache',
  ],
  'CRM_Contact_DAO_Group' => [
    'name' => 'Group',
    'class' => 'CRM_Contact_DAO_Group',
    'table' => 'civicrm_group',
  ],
  'CRM_Contact_DAO_SubscriptionHistory' => [
    'name' => 'SubscriptionHistory',
    'class' => 'CRM_Contact_DAO_SubscriptionHistory',
    'table' => 'civicrm_subscription_history',
  ],
  'CRM_Contact_DAO_GroupContactCache' => [
    'name' => 'GroupContactCache',
    'class' => 'CRM_Contact_DAO_GroupContactCache',
    'table' => 'civicrm_group_contact_cache',
  ],
  'CRM_Contact_DAO_GroupNesting' => [
    'name' => 'GroupNesting',
    'class' => 'CRM_Contact_DAO_GroupNesting',
    'table' => 'civicrm_group_nesting',
  ],
  'CRM_Contact_DAO_GroupOrganization' => [
    'name' => 'GroupOrganization',
    'class' => 'CRM_Contact_DAO_GroupOrganization',
    'table' => 'civicrm_group_organization',
  ],
  'CRM_Mailing_Event_DAO_Subscribe' => [
    'name' => 'Subscribe',
    'class' => 'CRM_Mailing_Event_DAO_Subscribe',
    'table' => 'civicrm_mailing_event_subscribe',
  ],
  'CRM_Mailing_Event_DAO_Confirm' => [
    'name' => 'Confirm',
    'class' => 'CRM_Mailing_Event_DAO_Confirm',
    'table' => 'civicrm_mailing_event_confirm',
  ],
  'CRM_Contribute_DAO_ContributionPage' => [
    'name' => 'ContributionPage',
    'class' => 'CRM_Contribute_DAO_ContributionPage',
    'table' => 'civicrm_contribution_page',
  ],
  'CRM_Contribute_DAO_Product' => [
    'name' => 'Product',
    'class' => 'CRM_Contribute_DAO_Product',
    'table' => 'civicrm_product',
  ],
  'CRM_Contribute_DAO_PremiumsProduct' => [
    'name' => 'PremiumsProduct',
    'class' => 'CRM_Contribute_DAO_PremiumsProduct',
    'table' => 'civicrm_premiums_product',
  ],
  'CRM_Contribute_DAO_Widget' => [
    'name' => 'Widget',
    'class' => 'CRM_Contribute_DAO_Widget',
    'table' => 'civicrm_contribution_widget',
  ],
  'CRM_Financial_DAO_PaymentProcessor' => [
    'name' => 'PaymentProcessor',
    'class' => 'CRM_Financial_DAO_PaymentProcessor',
    'table' => 'civicrm_payment_processor',
  ],
  'CRM_Financial_DAO_PaymentToken' => [
    'name' => 'PaymentToken',
    'class' => 'CRM_Financial_DAO_PaymentToken',
    'table' => 'civicrm_payment_token',
  ],
  'CRM_SMS_DAO_Provider' => [
    'name' => 'Provider',
    'class' => 'CRM_SMS_DAO_Provider',
    'table' => 'civicrm_sms_provider',
  ],
  'CRM_Member_DAO_MembershipType' => [
    'name' => 'MembershipType',
    'class' => 'CRM_Member_DAO_MembershipType',
    'table' => 'civicrm_membership_type',
  ],
  'CRM_Member_DAO_MembershipBlock' => [
    'name' => 'MembershipBlock',
    'class' => 'CRM_Member_DAO_MembershipBlock',
    'table' => 'civicrm_membership_block',
  ],
  'CRM_Case_DAO_Case' => [
    'name' => 'Case',
    'class' => 'CRM_Case_DAO_Case',
    'table' => 'civicrm_case',
  ],
  'CRM_Case_DAO_CaseContact' => [
    'name' => 'CaseContact',
    'class' => 'CRM_Case_DAO_CaseContact',
    'table' => 'civicrm_case_contact',
  ],
  'CRM_Pledge_DAO_Pledge' => [
    'name' => 'Pledge',
    'class' => 'CRM_Pledge_DAO_Pledge',
    'table' => 'civicrm_pledge',
  ],
  'CRM_Report_DAO_ReportInstance' => [
    'name' => 'ReportInstance',
    'class' => 'CRM_Report_DAO_ReportInstance',
    'table' => 'civicrm_report_instance',
  ],
  'CRM_Price_DAO_PriceSet' => [
    'name' => 'PriceSet',
    'class' => 'CRM_Price_DAO_PriceSet',
    'table' => 'civicrm_price_set',
  ],
  'CRM_Price_DAO_PriceSetEntity' => [
    'name' => 'PriceSetEntity',
    'class' => 'CRM_Price_DAO_PriceSetEntity',
    'table' => 'civicrm_price_set_entity',
  ],
  'CRM_Core_DAO_County' => [
    'name' => 'County',
    'class' => 'CRM_Core_DAO_County',
    'table' => 'civicrm_county',
  ],
  'CRM_Core_DAO_Dashboard' => [
    'name' => 'Dashboard',
    'class' => 'CRM_Core_DAO_Dashboard',
    'table' => 'civicrm_dashboard',
  ],
  'CRM_Core_DAO_Discount' => [
    'name' => 'Discount',
    'class' => 'CRM_Core_DAO_Discount',
    'table' => 'civicrm_discount',
  ],
  'CRM_Core_DAO_EntityFile' => [
    'name' => 'EntityFile',
    'class' => 'CRM_Core_DAO_EntityFile',
    'table' => 'civicrm_entity_file',
  ],
  'CRM_Core_DAO_EntityTag' => [
    'name' => 'EntityTag',
    'class' => 'CRM_Core_DAO_EntityTag',
    'table' => 'civicrm_entity_tag',
  ],
  'CRM_Core_DAO_UFGroup' => [
    'name' => 'UFGroup',
    'class' => 'CRM_Core_DAO_UFGroup',
    'table' => 'civicrm_uf_group',
  ],
  'CRM_Core_DAO_UFField' => [
    'name' => 'UFField',
    'class' => 'CRM_Core_DAO_UFField',
    'table' => 'civicrm_uf_field',
  ],
  'CRM_Core_DAO_UFJoin' => [
    'name' => 'UFJoin',
    'class' => 'CRM_Core_DAO_UFJoin',
    'table' => 'civicrm_uf_join',
  ],
  'CRM_Core_DAO_ActionSchedule' => [
    'name' => 'ActionSchedule',
    'class' => 'CRM_Core_DAO_ActionSchedule',
    'table' => 'civicrm_action_schedule',
  ],
  'CRM_Core_DAO_ActionLog' => [
    'name' => 'ActionLog',
    'class' => 'CRM_Core_DAO_ActionLog',
    'table' => 'civicrm_action_log',
  ],
  'CRM_Contact_DAO_DashboardContact' => [
    'name' => 'DashboardContact',
    'class' => 'CRM_Contact_DAO_DashboardContact',
    'table' => 'civicrm_dashboard_contact',
  ],
  'CRM_Contact_DAO_Relationship' => [
    'name' => 'Relationship',
    'class' => 'CRM_Contact_DAO_Relationship',
    'table' => 'civicrm_relationship',
  ],
  'CRM_Mailing_DAO_Mailing' => [
    'name' => 'Mailing',
    'class' => 'CRM_Mailing_DAO_Mailing',
    'table' => 'civicrm_mailing',
  ],
  'CRM_Mailing_DAO_MailingGroup' => [
    'name' => 'MailingGroup',
    'class' => 'CRM_Mailing_DAO_MailingGroup',
    'table' => 'civicrm_mailing_group',
  ],
  'CRM_Mailing_DAO_TrackableURL' => [
    'name' => 'TrackableURL',
    'class' => 'CRM_Mailing_DAO_TrackableURL',
    'table' => 'civicrm_mailing_trackable_url',
  ],
  'CRM_Mailing_DAO_MailingJob' => [
    'name' => 'MailingJob',
    'class' => 'CRM_Mailing_DAO_MailingJob',
    'table' => 'civicrm_mailing_job',
  ],
  'CRM_Mailing_DAO_Recipients' => [
    'name' => 'Recipients',
    'class' => 'CRM_Mailing_DAO_Recipients',
    'table' => 'civicrm_mailing_recipients',
  ],
  'CRM_Mailing_DAO_Spool' => [
    'name' => 'Spool',
    'class' => 'CRM_Mailing_DAO_Spool',
    'table' => 'civicrm_mailing_spool',
  ],
  'CRM_Mailing_Event_DAO_Queue' => [
    'name' => 'Queue',
    'class' => 'CRM_Mailing_Event_DAO_Queue',
    'table' => 'civicrm_mailing_event_queue',
  ],
  'CRM_Mailing_Event_DAO_Bounce' => [
    'name' => 'Bounce',
    'class' => 'CRM_Mailing_Event_DAO_Bounce',
    'table' => 'civicrm_mailing_event_bounce',
  ],
  'CRM_Mailing_Event_DAO_Delivered' => [
    'name' => 'Delivered',
    'class' => 'CRM_Mailing_Event_DAO_Delivered',
    'table' => 'civicrm_mailing_event_delivered',
  ],
  'CRM_Mailing_Event_DAO_Forward' => [
    'name' => 'Forward',
    'class' => 'CRM_Mailing_Event_DAO_Forward',
    'table' => 'civicrm_mailing_event_forward',
  ],
  'CRM_Mailing_Event_DAO_Opened' => [
    'name' => 'Opened',
    'class' => 'CRM_Mailing_Event_DAO_Opened',
    'table' => 'civicrm_mailing_event_opened',
  ],
  'CRM_Mailing_Event_DAO_Reply' => [
    'name' => 'Reply',
    'class' => 'CRM_Mailing_Event_DAO_Reply',
    'table' => 'civicrm_mailing_event_reply',
  ],
  'CRM_Mailing_Event_DAO_TrackableURLOpen' => [
    'name' => 'TrackableURLOpen',
    'class' => 'CRM_Mailing_Event_DAO_TrackableURLOpen',
    'table' => 'civicrm_mailing_event_trackable_url_open',
  ],
  'CRM_Mailing_Event_DAO_Unsubscribe' => [
    'name' => 'Unsubscribe',
    'class' => 'CRM_Mailing_Event_DAO_Unsubscribe',
    'table' => 'civicrm_mailing_event_unsubscribe',
  ],
  'CRM_Contribute_DAO_ContributionRecur' => [
    'name' => 'ContributionRecur',
    'class' => 'CRM_Contribute_DAO_ContributionRecur',
    'table' => 'civicrm_contribution_recur',
  ],
  'CRM_Financial_DAO_FinancialTrxn' => [
    'name' => 'FinancialTrxn',
    'class' => 'CRM_Financial_DAO_FinancialTrxn',
    'table' => 'civicrm_financial_trxn',
  ],
  'CRM_Member_DAO_Membership' => [
    'name' => 'Membership',
    'class' => 'CRM_Member_DAO_Membership',
    'table' => 'civicrm_membership',
  ],
  'CRM_Member_DAO_MembershipLog' => [
    'name' => 'MembershipLog',
    'class' => 'CRM_Member_DAO_MembershipLog',
    'table' => 'civicrm_membership_log',
  ],
  'CRM_Activity_DAO_Activity' => [
    'name' => 'Activity',
    'class' => 'CRM_Activity_DAO_Activity',
    'table' => 'civicrm_activity',
  ],
  'CRM_Activity_DAO_ActivityContact' => [
    'name' => 'ActivityContact',
    'class' => 'CRM_Activity_DAO_ActivityContact',
    'table' => 'civicrm_activity_contact',
  ],
  'CRM_Case_DAO_CaseActivity' => [
    'name' => 'CaseActivity',
    'class' => 'CRM_Case_DAO_CaseActivity',
    'table' => 'civicrm_case_activity',
  ],
  'CRM_Price_DAO_PriceField' => [
    'name' => 'PriceField',
    'class' => 'CRM_Price_DAO_PriceField',
    'table' => 'civicrm_price_field',
  ],
  'CRM_Price_DAO_PriceFieldValue' => [
    'name' => 'PriceFieldValue',
    'class' => 'CRM_Price_DAO_PriceFieldValue',
    'table' => 'civicrm_price_field_value',
  ],
  'CRM_PCP_DAO_PCPBlock' => [
    'name' => 'PCPBlock',
    'class' => 'CRM_PCP_DAO_PCPBlock',
    'table' => 'civicrm_pcp_block',
  ],
  'CRM_Core_DAO_Address' => [
    'name' => 'Address',
    'class' => 'CRM_Core_DAO_Address',
    'table' => 'civicrm_address',
  ],
  'CRM_Core_DAO_LocBlock' => [
    'name' => 'LocBlock',
    'class' => 'CRM_Core_DAO_LocBlock',
    'table' => 'civicrm_loc_block',
  ],
  'CRM_Contact_DAO_GroupContact' => [
    'name' => 'GroupContact',
    'class' => 'CRM_Contact_DAO_GroupContact',
    'table' => 'civicrm_group_contact',
  ],
  'CRM_Contribute_DAO_Contribution' => [
    'name' => 'Contribution',
    'class' => 'CRM_Contribute_DAO_Contribution',
    'table' => 'civicrm_contribution',
  ],
  'CRM_Contribute_DAO_ContributionProduct' => [
    'name' => 'ContributionProduct',
    'class' => 'CRM_Contribute_DAO_ContributionProduct',
    'table' => 'civicrm_contribution_product',
  ],
  'CRM_Contribute_DAO_ContributionSoft' => [
    'name' => 'ContributionSoft',
    'class' => 'CRM_Contribute_DAO_ContributionSoft',
    'table' => 'civicrm_contribution_soft',
  ],
  'CRM_Financial_DAO_EntityFinancialTrxn' => [
    'name' => 'EntityFinancialTrxn',
    'class' => 'CRM_Financial_DAO_EntityFinancialTrxn',
    'table' => 'civicrm_entity_financial_trxn',
  ],
  'CRM_Member_DAO_MembershipPayment' => [
    'name' => 'MembershipPayment',
    'class' => 'CRM_Member_DAO_MembershipPayment',
    'table' => 'civicrm_membership_payment',
  ],
  'CRM_Event_DAO_Event' => [
    'name' => 'Event',
    'class' => 'CRM_Event_DAO_Event',
    'table' => 'civicrm_event',
  ],
  'CRM_Event_DAO_Participant' => [
    'name' => 'Participant',
    'class' => 'CRM_Event_DAO_Participant',
    'table' => 'civicrm_participant',
  ],
  'CRM_Event_DAO_ParticipantPayment' => [
    'name' => 'ParticipantPayment',
    'class' => 'CRM_Event_DAO_ParticipantPayment',
    'table' => 'civicrm_participant_payment',
  ],
  'CRM_Event_Cart_DAO_EventInCart' => [
    'name' => 'EventInCart',
    'class' => 'CRM_Event_Cart_DAO_EventInCart',
    'table' => 'civicrm_events_in_carts',
  ],
  'CRM_Pledge_DAO_PledgePayment' => [
    'name' => 'PledgePayment',
    'class' => 'CRM_Pledge_DAO_PledgePayment',
    'table' => 'civicrm_pledge_payment',
  ],
  'CRM_Price_DAO_LineItem' => [
    'name' => 'LineItem',
    'class' => 'CRM_Price_DAO_LineItem',
    'table' => 'civicrm_line_item',
  ],
];
